GenerationConfig

Struct GenerationConfig 

pub struct GenerationConfig {
Show 15 fields pub temperature: Option<f32>, pub top_p: Option<f32>, pub top_k: Option<i32>, pub seed: Option<i32>, pub max_output_tokens: Option<i32>, pub candidate_count: Option<i32>, pub stop_sequences: Option<Vec<String>>, pub response_mime_type: Option<String>, pub response_schema: Option<Value>, pub response_json_schema: Option<Value>, pub response_modalities: Option<Vec<String>>, pub image_config: Option<ImageConfig>, pub speech_config: Option<SpeechConfig>, pub thinking_config: Option<ThinkingConfig>, pub media_resolution: Option<MediaResolutionLevel>,
}
๐Ÿ‘ŽDeprecated since 1.8.0:

Use crate::interactions::InteractionGenerationConfig instead

Configuration for generation

Fields

temperature: Option<f32>
๐Ÿ‘ŽDeprecated since 1.8.0:

Use crate::interactions::InteractionGenerationConfig instead

The temperature for the model (0.0 to 1.0)

Controls the randomness of the output. Higher values (e.g., 0.9) make output more random, lower values (e.g., 0.1) make output more deterministic.

top_p: Option<f32>
๐Ÿ‘ŽDeprecated since 1.8.0:

Use crate::interactions::InteractionGenerationConfig instead

The top-p value for the model (0.0 to 1.0)

For each token generation step, the model considers the top_p percentage of probability mass for potential token choices. Lower values are more selective, higher values allow more variety.

top_k: Option<i32>
๐Ÿ‘ŽDeprecated since 1.8.0:

Use crate::interactions::InteractionGenerationConfig instead

The top-k value for the model

For each token generation step, the model considers the top_k most likely tokens. Lower values are more selective, higher values allow more variety.

seed: Option<i32>
๐Ÿ‘ŽDeprecated since 1.8.0:

Use crate::interactions::InteractionGenerationConfig instead

Seed used in decoding.

By default, the model uses a random value for each request if a seed is not provided. Setting a specific seed, along with consistent values for other parameters like temperature, can make the model return the same response for repeated requests with the same input. Identical outputs are not guaranteed across all runs, due to backend infrastructure variations, but it provides a โ€œbest effortโ€ for reproducibility.

max_output_tokens: Option<i32>
๐Ÿ‘ŽDeprecated since 1.8.0:

Use crate::interactions::InteractionGenerationConfig instead

The maximum number of tokens to generate

Limits the length of the generated content. One token is roughly 4 characters.

candidate_count: Option<i32>
๐Ÿ‘ŽDeprecated since 1.8.0:

Use crate::interactions::InteractionGenerationConfig instead

The candidate count

Number of alternative responses to generate.

stop_sequences: Option<Vec<String>>
๐Ÿ‘ŽDeprecated since 1.8.0:

Use crate::interactions::InteractionGenerationConfig instead

Whether to stop on specific sequences

The model will stop generating content when it encounters any of these sequences.

response_mime_type: Option<String>
๐Ÿ‘ŽDeprecated since 1.8.0:

Use crate::interactions::InteractionGenerationConfig instead

The response mime type

Specifies the format of the modelโ€™s response.

response_schema: Option<Value>
๐Ÿ‘ŽDeprecated since 1.8.0:

Use crate::interactions::InteractionGenerationConfig instead

The response schema

Specifies the JSON schema for structured responses.

response_json_schema: Option<Value>
๐Ÿ‘ŽDeprecated since 1.8.0:

Use crate::interactions::InteractionGenerationConfig instead

The response JSON schema (strict mode).

Prefer this field for modern Gemini models that support JSON Schema natively.

response_modalities: Option<Vec<String>>
๐Ÿ‘ŽDeprecated since 1.8.0:

Use crate::interactions::InteractionGenerationConfig instead

Response modalities (for TTS and other multimodal outputs)

image_config: Option<ImageConfig>
๐Ÿ‘ŽDeprecated since 1.8.0:

Use crate::interactions::InteractionGenerationConfig instead

Optional. Config for image generation. An error will be returned if this field is set for models that donโ€™t support these config options.

speech_config: Option<SpeechConfig>
๐Ÿ‘ŽDeprecated since 1.8.0:

Use crate::interactions::InteractionGenerationConfig instead

Speech configuration for text-to-speech generation

thinking_config: Option<ThinkingConfig>
๐Ÿ‘ŽDeprecated since 1.8.0:

Use crate::interactions::InteractionGenerationConfig instead

The thinking configuration

Configuration for the modelโ€™s thinking process (Gemini 2.5 and Gemini 3 series).

media_resolution: Option<MediaResolutionLevel>
๐Ÿ‘ŽDeprecated since 1.8.0:

Use crate::interactions::InteractionGenerationConfig instead

Global media resolution for all images and PDFs. Controls the resolution used for inline image and PDF data, affecting token usage. Can be overridden per-part using the Part::InlineData media_resolution field.