Module model

Module model 

Structs

AllowedTools
AllowlistEntry
CodeExecutionCallArguments
CreateInteractionRequest
Request body for creating an interaction.
EnvironmentNetworkEgressAllowlist
ExaAISearchConfig
GoogleMapsCallArguments
GoogleMapsResultItem
GoogleMapsResultPlaces
GoogleSearchCallArguments
GoogleSearchResultItem
GroundingToolCount
HybridSearch
Hybrid search configuration.
Interaction
Interaction resource — represents a complete interaction.
InteractionError
InteractionGenerationConfig
Model interaction configuration (mutually exclusive with agent_config).
InteractionSpeechConfig
InteractionUsage
Token usage statistics.
ModalityTokens
ParallelAISearchConfig
RagFilter
Filter configuration for RAG retrieval.
RagResource
RagRetrievalConfig
Retrieval configuration for RAG queries.
RagStoreConfig
Ranking
Ranking and reranking configuration.
ReviewSnippet
Status
ToolChoiceConfig
UrlContextCallArguments
UrlContextResultData
VideoConfig
WebhookConfig

Enums

AgentConfig
Agent configuration (mutually exclusive with generation_config).
Annotation
Citation annotation — type-tagged polymorphic.
AspectRatio
AudioMimeType
AudioOutputMimeType
CodeLanguage
ComputerUseEnvironment
ComputerUseSafetyPolicy
DeliveryMode
DocumentMimeType
EnvironmentConfig
Environment configuration — type-tagged polymorphic.
EnvironmentConfigOrString
Environment configuration — can be a full config object or just an ID string.
EnvironmentNetwork
Network configuration — can be an allowlist object or “disabled” string.
EnvironmentSource
Environment source — type-tagged polymorphic.
GoogleSearchType
GroundingType
ImageMimeType
ImageOutputMimeType
ImageSize
InteractionContent
Input content for interactions — type-tagged polymorphic.
InteractionInput
Input can be a string, single Content, Content array, or Step array.
InteractionStatus
Interaction status.
InteractionThinkingLevel
InteractionTool
Tool declaration — type-tagged polymorphic.
MediaResolution
ResponseFormat
Response format configuration — type-tagged polymorphic.
ResponseModality
RetrievalType
ServiceTier
Step
A single step in an interaction — type-tagged polymorphic.
StepResult
Function result can be a content array, JSON object, or string.
StepResultContent
Content items allowed in step results (text or image only).
TextMimeType
ThinkingSummaries
ThoughtSummaryContent
Thought summary content — polymorphic.
ToolChoiceMode
UrlContextStatus
VideoAspectRatio
VideoMimeType
VideoTask
Visualization