Step

Enum Step 

pub enum Step {
Show 17 variants UserInput { content: Vec<InteractionContent>, }, ModelOutput { content: Vec<InteractionContent>, error: Option<Status>, }, Thought { signature: Option<String>, summary: Vec<ThoughtSummaryContent>, }, FunctionCall { name: String, arguments: Value, id: String, }, FunctionResult { name: Option<String>, call_id: String, result: StepResult, is_error: Option<bool>, }, CodeExecutionCall { arguments: CodeExecutionCallArguments, id: String, signature: Option<String>, }, CodeExecutionResult { result: String, call_id: String, is_error: Option<bool>, signature: Option<String>, }, UrlContextCall { id: String, signature: Option<String>, arguments: UrlContextCallArguments, }, UrlContextResult { result: UrlContextResultData, is_error: Option<bool>, call_id: String, signature: Option<String>, }, GoogleSearchCall { arguments: GoogleSearchCallArguments, search_type: Option<GoogleSearchType>, id: String, signature: Option<String>, }, GoogleSearchResult { result: GoogleSearchResultItem, is_error: Option<bool>, call_id: String, signature: Option<String>, }, GoogleMapsCall { arguments: Option<GoogleMapsCallArguments>, id: String, signature: Option<String>, }, GoogleMapsResult { result: GoogleMapsResultItem, call_id: String, signature: Option<String>, }, FileSearchCall { id: String, signature: Option<String>, }, FileSearchResult { citations: Vec<Annotation>, call_id: String, signature: Option<String>, }, McpServerToolCall { name: String, server_name: String, arguments: Value, id: String, }, McpServerToolResult { name: Option<String>, server_name: Option<String>, call_id: String, result: StepResult, },
}
A single step in an interaction — type-tagged polymorphic.

Each step represents a typed action in the interaction history: user input, model output, thoughts, function calls, tool invocations, etc.

Variants



UserInput

Fields



ModelOutput

Fields



Thought

Fields

signature: Option<String>


FunctionCall

Fields

name: String
arguments: Value


FunctionResult

Fields

call_id: String
result: StepResult
is_error: Option<bool>


CodeExecutionCall

Fields

signature: Option<String>


CodeExecutionResult

Fields

result: String
call_id: String
is_error: Option<bool>
signature: Option<String>


UrlContextCall

Fields

signature: Option<String>


UrlContextResult

Fields

is_error: Option<bool>
call_id: String
signature: Option<String>


GoogleSearchCall

Fields

signature: Option<String>


GoogleSearchResult

Fields

is_error: Option<bool>
call_id: String
signature: Option<String>


GoogleMapsCall

Fields

signature: Option<String>


GoogleMapsResult

Fields

call_id: String
signature: Option<String>


FileSearchCall

Fields

signature: Option<String>


FileSearchResult

Fields

citations: Vec<Annotation>
call_id: String
signature: Option<String>


McpServerToolCall

Fields

name: String
server_name: String
arguments: Value


McpServerToolResult

Fields

server_name: Option<String>
call_id: String
result: StepResult