Structs
- Allowed
Tools - Allowlist
Entry - Code
Execution Call Arguments - Create
Interaction Request - Request body for creating an interaction.
- Environment
Network Egress Allowlist - ExaAI
Search Config - Google
Maps Call Arguments - Google
Maps Result Item - Google
Maps Result Places - Google
Search Call Arguments - Google
Search Result Item - Grounding
Tool Count - Hybrid
Search - Hybrid search configuration.
- Interaction
- Interaction resource — represents a complete interaction.
- Interaction
Error - Interaction
Generation Config - Model interaction configuration (mutually exclusive with agent_config).
- Interaction
Speech Config - Interaction
Usage - Token usage statistics.
- Modality
Tokens - ParallelAI
Search Config - RagFilter
- Filter configuration for RAG retrieval.
- RagResource
- RagRetrieval
Config - Retrieval configuration for RAG queries.
- RagStore
Config - Ranking
- Ranking and reranking configuration.
- Review
Snippet - Status
- Tool
Choice Config - UrlContext
Call Arguments - UrlContext
Result Data - Video
Config - Webhook
Config
Enums
- Agent
Config - Agent configuration (mutually exclusive with generation_config).
- Annotation
- Citation annotation — type-tagged polymorphic.
- Aspect
Ratio - Audio
Mime Type - Audio
Output Mime Type - Code
Language - Computer
UseEnvironment - Computer
UseSafety Policy - Delivery
Mode - Document
Mime Type - Environment
Config - Environment configuration — type-tagged polymorphic.
- Environment
Config OrString - Environment configuration — can be a full config object or just an ID string.
- Environment
Network - Network configuration — can be an allowlist object or “disabled” string.
- Environment
Source - Environment source — type-tagged polymorphic.
- Google
Search Type - Grounding
Type - Image
Mime Type - Image
Output Mime Type - Image
Size - Interaction
Content - Input content for interactions — type-tagged polymorphic.
- Interaction
Input - Input can be a string, single Content, Content array, or Step array.
- Interaction
Status - Interaction status.
- Interaction
Thinking Level - Interaction
Tool - Tool declaration — type-tagged polymorphic.
- Media
Resolution - Response
Format - Response format configuration — type-tagged polymorphic.
- Response
Modality - Retrieval
Type - Service
Tier - Step
- A single step in an interaction — type-tagged polymorphic.
- Step
Result - Function result can be a content array, JSON object, or string.
- Step
Result Content - Content items allowed in step results (text or image only).
- Text
Mime Type - Thinking
Summaries - Thought
Summary Content - Thought summary content — polymorphic.
- Tool
Choice Mode - UrlContext
Status - Video
Aspect Ratio - Video
Mime Type - Video
Task - Visualization